# Copyright (c) 2024 Microsoft Corporation. All rights reserved.
# Licensed under the MIT license. See LICENSE file in the project.
#
import pytest

from intelligence_toolkit.AI.text_splitter import TextSplitter


@pytest.fixture()
def text_splitter():
    return TextSplitter(20)


@pytest.fixture()
def text_example():
    return """
    The Intelligence toolkit aims to detect and explain patterns, relationships, and risks in data provided by the user. It is not designed to make decisions or take actions based on these findings.
    The statistical "insights" that it detects may not be insightful or useful in practice, and will inherit any biases, errors, or omissions present in the data collecting/generating process. These may be further amplified by the AI interpretations and reports generated by the toolkit.
    The generative AI model may itself introduce additional statistical or societal biases, or fabricate information not present in its grounding data, as a consequence of its training and design.
    Users should be experts in their domain, familiar with the data, and both able and willing to evaluate the quality of the insights and AI interpretations before taking action.
    The system was designed and tested for the processing of English language data and the creation of English language outputs. Performance in other languages may vary and should be assessed by someone who is both an expert on the data and a native speaker of that language.
"""


def test_text_splitter(text_splitter, text_example):
    chunks = text_splitter.split(text_example)

    expected_chunks = [
        "The Intelligence toolkit aims to detect and explain patterns, relationships, and risks in data provided by the",
        "user. It is not designed to make decisions or take actions based on these findings.",
        'The statistical "insights" that it detects may not be insightful or useful in practice, and will',
        "inherit any biases, errors, or omissions present in the data collecting/generating process. These may",
        "be further amplified by the AI interpretations and reports generated by the toolkit.",
        "The generative AI model may itself introduce additional statistical or societal biases, or fabricate information not present in",
        "its grounding data, as a consequence of its training and design.",
        "Users should be experts in their domain, familiar with the data, and both able and willing to evaluate",
        "the quality of the insights and AI interpretations before taking action.",
        "The system was designed and tested for the processing of English language data and the creation of English language",
        "outputs. Performance in other languages may vary and should be assessed by someone who is both an expert on",
        "the data and a native speaker of that language.",
    ]
    assert chunks == expected_chunks


def test_text_splitter_empty_input(text_splitter):
    text = ""
    chunks = text_splitter.split(text)
    assert chunks == []
